@@ -55,6 +55,16 @@ class AccountsService: public QObject
                 READ failedLogins
                 WRITE setFailedLogins
                 NOTIFY failedLoginsChanged)
+    Q_PROPERTY(bool hereEnabled
+               READ hereEnabled
+               WRITE setHereEnabled
+               NOTIFY hereEnabledChanged)
+    Q_PROPERTY(QString hereLicensePath
+               READ hereLicensePath
+               NOTIFY hereLicensePathChanged)
+    Q_PROPERTY(bool hereLicensePathValid // qml sees a null string as "", so we use proxy setting for that
+               READ hereLicensePathValid
+               NOTIFY hereLicensePathChanged)
 
 public:
     enum PasswordDisplayHint {
@@ -75,6 +85,10 @@ public:
     PasswordDisplayHint passwordDisplayHint() const;
     uint failedLogins() const;
     void setFailedLogins(uint failedLogins);
+    bool hereEnabled() const;
+    void setHereEnabled(bool enabled);
+    QString hereLicensePath() const;
+    bool hereLicensePathValid() const;
 
 Q_SIGNALS:
     void userChanged();
@@ -85,6 +99,8 @@ Q_SIGNALS:
     void statsWelcomeScreenChanged();
     void passwordDisplayHintChanged();
     void failedLoginsChanged();
+    void hereEnabledChanged();
+    void hereLicensePathChanged();
 
 private Q_SLOTS:
     void propertiesChanged(const QString &user, const QString &interface, const QStringList &changed);
@@ -98,6 +114,8 @@ private:
     void updateStatsWelcomeScreen();
     void updatePasswordDisplayHint();
     void updateFailedLogins();
+    void updateHereEnabled();
+    void updateHereLicensePath();
 
     AccountsServiceDBusAdaptor *m_service;
     QString m_user;
@@ -108,6 +126,8 @@ private:
     bool m_statsWelcomeScreen;
     PasswordDisplayHint m_passwordDisplayHint;
     uint m_failedLogins;
+    bool m_hereEnabled;
+    QString m_hereLicensePath;
 };
 
 #endif
