@@ -82,16 +82,16 @@ var kArtShapeHolderCode = 'Item  { \n\
                                             height = Qt.binding(function() { return image.status !== Image.Ready ? 0 : image.height }); \n\
                                         } \n\
                                     } \n\
-                                    image: CroppedImageMinimumSourceSize { \n\
+                                    CroppedImageMinimumSourceSize { \n\
+                                        id: artImage; \n\
                                         objectName: "artImage"; \n\
-                                        property bool doLoadSource: !NetworkingStatus.limitedBandwith; \n\
-                                        source: { if (root.visible) doLoadSource = true; return doLoadSource && cardData && cardData["art"] || ""; } \n\
-                                        cache: true; \n\
+                                        source: cardData && cardData["art"] || ""; \n\
                                         asynchronous: root.asynchronous; \n\
                                         visible: false; \n\
                                         width: %2; \n\
                                         height: %3; \n\
                                     } \n\
+                                    image: artImage.image; \n\
                                 } \n\
                             } \n\
                         }\n';
@@ -181,11 +181,11 @@ var kMascotShapeLoaderCode = 'Loader { \n\
                                 id: mascotShapeLoader; \n\
                                 objectName: "mascotShapeLoader"; \n\
                                 asynchronous: root.asynchronous; \n\
-                                active: mascotImage.status === Image.Ready; \n\
+                                active: mascotImage.image.status === Image.Ready; \n\
                                 visible: showHeader && active && status == Loader.Ready; \n\
                                 width: units.gu(6); \n\
                                 height: units.gu(5.625); \n\
-                                sourceComponent: UbuntuShape { image: mascotImage } \n\
+                                sourceComponent: UbuntuShape { image: mascotImage.image } \n\
                                 anchors { %1 } \n\
                             }\n';
 
@@ -195,8 +195,7 @@ var kMascotImageCode = 'CroppedImageMinimumSourceSize { \n\
                             id: mascotImage; \n\
                             objectName: "mascotImage"; \n\
                             anchors { %1 } \n\
-                            property bool doLoadSource: !NetworkingStatus.limitedBandwith; \n\
-                            source: { if (root.visible) doLoadSource = true; return doLoadSource && cardData && cardData["mascot"] || ""; } \n\
+                            source: cardData && cardData["mascot"] || ""; \n\
                             width: units.gu(6); \n\
                             height: units.gu(5.625); \n\
                             horizontalAlignment: Image.AlignHCenter; \n\
@@ -225,7 +224,9 @@ var kTitleLabelCode = 'Label { \n\
 
 // %1 is used as extra anchors of emblemIcon
 // %2 is used as color of emblemIcon
-var kEmblemIconCode = 'StatusIcon { \n\
+// FIXME The width code is a
+// Workaround for bug https://bugs.launchpad.net/ubuntu/+source/ubuntu-ui-toolkit/+bug/1421293
+var kEmblemIconCode = 'Icon { \n\
                             id: emblemIcon; \n\
                             objectName: "emblemIcon"; \n\
                             anchors { \n\
@@ -236,6 +237,7 @@ var kEmblemIconCode = 'StatusIcon { \n\
                             source: cardData && cardData["emblem"] || ""; \n\
                             color: %2; \n\
                             height: source != "" ? titleLabel.font.pixelSize : 0; \n\
+                            width: implicitWidth > 0 && implicitHeight > 0 ? (implicitWidth / implicitHeight * height) : implicitWidth; \n\
                         }\n';
 
 // %1 is used as anchors of touchdown effect
@@ -256,6 +258,7 @@ var kSubtitleLabelCode = 'Label { \n\
                             anchors { %1 } \n\
                             anchors.topMargin: units.dp(2); \n\
                             elide: Text.ElideRight; \n\
+                            maximumLineCount: 1; \n\
                             fontSize: "x-small"; \n\
                             font.pixelSize: Math.round(FontUtils.sizeToPixels(fontSize) * fontScale); \n\
                             color: %2; \n\
@@ -313,13 +316,16 @@ function cardString(template, components) {
                 readonly property string title: cardData && cardData["title"] || ""; \n\
                 property bool asynchronous: true; \n\
                 property bool showHeader: true; \n\
-                implicitWidth: childrenRect.width; \n';
+                implicitWidth: childrenRect.width; \n\
+                enabled: root.template == null ? true : (root.template["non-interactive"] !== undefined ? !root.template["non-interactive"] : true); \n\
+                \n';
 
     var hasArt = components["art"] && components["art"]["field"] || false;
     var hasSummary = components["summary"] || false;
     var artAndSummary = hasArt && hasSummary;
     var isHorizontal = template["card-layout"] === "horizontal";
-    var hasBackground = !isHorizontal && (template["card-background"] || components["background"] || artAndSummary);
+    var hasBackground = (!isHorizontal && (template["card-background"] || components["background"] || artAndSummary)) ||
+                        (hasSummary && (template["card-background"] || components["background"]));
     var hasTitle = components["title"] || false;
     var hasMascot = components["mascot"] || false;
     var hasEmblem = components["emblem"] && !(hasMascot && template["card-size"] === "small") || false;
@@ -433,7 +439,7 @@ function cardString(template, components) {
             mascotShapeCode = kMascotShapeLoaderCode.arg(mascotAnchors);
         }
 
-        var mascotImageVisible = useMascotShape ? 'false' : 'showHeader && resized';
+        var mascotImageVisible = useMascotShape ? 'false' : 'showHeader';
         mascotCode = kMascotImageCode.arg(mascotAnchors).arg(mascotImageVisible);
     }
 
@@ -653,7 +659,6 @@ function createCardComponent(parent, template, components) {
     var imports = 'import QtQuick 2.2; \n\
                    import Ubuntu.Components 1.1; \n\
                    import Ubuntu.Settings.Components 0.1; \n\
-                   import Ubuntu.Connectivity 1.0; \n\
                    import Dash 0.1;\n\
                    import Utils 0.1;\n';
     var card = cardString(template, components);
