@@ -56,6 +56,7 @@ IndicatorsModel::IndicatorsModel(QObject *parent)
     m_manager = new IndicatorsManager(this);
     QObject::connect(m_manager, SIGNAL(indicatorLoaded(const QString&)), this, SLOT(onIndicatorLoaded(const QString&)));
     QObject::connect(m_manager, SIGNAL(indicatorAboutToBeUnloaded(const QString&)), this, SLOT(onIndicatorAboutToBeUnloaded(const QString&)));
+    QObject::connect(m_manager, SIGNAL(profileChanged(const QString&)), this, SIGNAL(profileChanged()));
 
     QObject::connect(this, SIGNAL(rowsInserted(const QModelIndex &, int, int)), this, SIGNAL(countChanged()));
     QObject::connect(this, SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this, SIGNAL(countChanged()));
@@ -80,15 +81,37 @@ int IndicatorsModel::count() const
     return rowCount();
 }
 
+/*!
+    \qmlproperty IndicatorsModel::profile
+    The indicator profile to use for the model.
+
+    \b Note: methods should only be called after the Component has completed.
+*/
+QString IndicatorsModel::profile() const
+{
+    return m_manager->profile();
+}
+
+/*!
+    \qmlproperty IndicatorsModel::setProfile
+    Set the indicator profile to use for the model.
+
+    \b Note: methods should only be called after the Component has completed.
+*/
+void IndicatorsModel::setProfile(const QString &profile)
+{
+    m_manager->setProfile(profile);
+}
+
 /*!
     \qmlmethod IndicatorsModel::unload()
 
     Load all indicators.
 */
-void IndicatorsModel::load(const QString& profile)
+void IndicatorsModel::load()
 {
     m_indicators.clear();
-    m_manager->load(profile);
+    m_manager->load();
 }
 
 /*!
@@ -202,8 +225,6 @@ QHash<int, QByteArray> IndicatorsModel::roleNames() const
     {
         roles[IndicatorsModelRole::Identifier] = "identifier";
         roles[IndicatorsModelRole::Position] = "position";
-        roles[IndicatorsModelRole::WidgetSource] = "widgetSource";
-        roles[IndicatorsModelRole::PageSource] = "pageSource";
         roles[IndicatorsModelRole::IndicatorProperties] = "indicatorProperties";
     }
     return roles;
@@ -248,10 +269,6 @@ QVariant IndicatorsModel::data(const QModelIndex &index, int role) const
                 return QVariant(indicator->indicatorProperties());
             }
             break;
-        case IndicatorsModelRole::WidgetSource:
-            return qmlDirectory()+"/Panel/Indicators/DefaultIndicatorWidget.qml";
-        case IndicatorsModelRole::PageSource:
-            return qmlDirectory()+"/Panel/Indicators/DefaultIndicatorPage.qml";
         default:
             break;
     }
