@@ -24,31 +24,37 @@
 #include "plugin.h"
 
 // local
+#include "actionrootstate.h"
 #include "indicators.h"
 #include "indicatorsmanager.h"
 #include "indicatorsmodel.h"
 #include "menucontentactivator.h"
+#include "modelactionrootstate.h"
 #include "modelprinter.h"
-#include "rootactionstate.h"
+#include "sharedunitymenumodel.h"
 #include "unitymenumodelcache.h"
 #include "unitymenumodelstack.h"
-#include "visibleindicatorsmodel.h"
+
+#include <unitymenumodel.h>
 
 static QObject* menuModelCacheSingleton(QQmlEngine* engine, QJSEngine* scriptEngine) {
   Q_UNUSED(engine);
   Q_UNUSED(scriptEngine);
-  return new UnityMenuModelCache;
+  return UnityMenuModelCache::singleton();
 }
 
-void Indicators2Plugin::registerTypes(const char *uri)
+void IndicatorsPlugin::registerTypes(const char *uri)
 {
+    qRegisterMetaType<UnityMenuModel*>("UnityMenuModel*");
+
     qmlRegisterType<IndicatorsManager>(uri, 0, 1, "IndicatorsManager");
     qmlRegisterType<IndicatorsModel>(uri, 0, 1, "IndicatorsModel");
     qmlRegisterType<MenuContentActivator>(uri, 0, 1, "MenuContentActivator");
     qmlRegisterType<UnityMenuModelStack>(uri, 0, 1, "UnityMenuModelStack");
-    qmlRegisterType<RootActionState>(uri, 0, 1, "RootActionState");
+    qmlRegisterType<ModelActionRootState>(uri, 0, 1, "ModelActionRootState");
+    qmlRegisterType<ActionRootState>(uri, 0, 1, "ActionRootState");
     qmlRegisterType<ModelPrinter>(uri, 0, 1, "ModelPrinter");
-    qmlRegisterType<VisibleIndicatorsModel>(uri, 0, 1, "VisibleIndicatorsModel");
+    qmlRegisterType<SharedUnityMenuModel>(uri, 0, 1, "SharedUnityMenuModel");
 
     qmlRegisterSingletonType<UnityMenuModelCache>(uri, 0, 1, "UnityMenuModelCache", menuModelCacheSingleton);
 
