@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Canonical Ltd.
+ * Copyright 2013-2014 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,7 @@
 #include "gsettings.h"
 #include "desktopfilehandler.h"
 #include "dbusinterface.h"
+#include "asadapter.h"
 
 #include <unity/shell/application/ApplicationInfoInterface.h>
 
@@ -34,26 +35,16 @@ LauncherModel::LauncherModel(QObject *parent):
     LauncherModelInterface(parent),
     m_settings(new GSettings(this)),
     m_dbusIface(new DBusInterface(this)),
+    m_asAdapter(new ASAdapter()),
     m_appManager(0)
 {
     connect(m_dbusIface, &DBusInterface::countChanged, this, &LauncherModel::countChanged);
     connect(m_dbusIface, &DBusInterface::countVisibleChanged, this, &LauncherModel::countVisibleChanged);
     connect(m_dbusIface, &DBusInterface::refreshCalled, this, &LauncherModel::refresh);
 
-    Q_FOREACH (const QString &entry, m_settings->storedApplications()) {
-        DesktopFileHandler desktopFile(entry);
-        if (!desktopFile.isValid()) {
-            qWarning() << "Couldn't find a .desktop file for" << entry << ". Skipping...";
-            continue;
-        }
+    connect(m_settings, &GSettings::changed, this, &LauncherModel::refresh);
 
-        LauncherItem *item = new LauncherItem(entry,
-                                              desktopFile.displayName(),
-                                              desktopFile.icon(),
-                                              this);
-        item->setPinned(true);
-        m_list.append(item);
-    }
+    refresh();
 }
 
 LauncherModel::~LauncherModel()
@@ -61,6 +52,8 @@ LauncherModel::~LauncherModel()
     while (!m_list.empty()) {
         m_list.takeFirst()->deleteLater();
     }
+
+    delete m_asAdapter;
 }
 
 int LauncherModel::rowCount(const QModelIndex &parent) const
@@ -173,22 +166,7 @@ void LauncherModel::pin(const QString &appId, int index)
 
 void LauncherModel::requestRemove(const QString &appId)
 {
-    int index = findApplication(appId);
-    if (index < 0) {
-        return;
-    }
-
-    if (m_appManager->findApplication(appId)) {
-        m_list.at(index)->setPinned(false);
-        QModelIndex modelIndex = this->index(index);
-        Q_EMIT dataChanged(modelIndex, modelIndex, QVector<int>() << RolePinned);
-        return;
-    }
-
-    beginRemoveRows(QModelIndex(), index, index);
-    m_list.takeAt(index)->deleteLater();
-    endRemoveRows();
-
+    unpin(appId);
     storeAppList();
 }
 
@@ -287,6 +265,15 @@ void LauncherModel::setApplicationManager(unity::shell::application::Application
     }
 }
 
+bool LauncherModel::onlyPinned() const
+{
+    return false;
+}
+
+void LauncherModel::setOnlyPinned(bool onlyPinned) {
+    Q_UNUSED(onlyPinned);
+    qWarning() << "This launcher implementation does not support showing only pinned apps";
+}
 
 void LauncherModel::storeAppList()
 {
@@ -297,6 +284,27 @@ void LauncherModel::storeAppList()
         }
     }
     m_settings->setStoredApplications(appIds);
+    m_asAdapter->syncItems(m_list);
+}
+
+void LauncherModel::unpin(const QString &appId)
+{
+    int index = findApplication(appId);
+    if (index < 0) {
+        return;
+    }
+
+    if (m_appManager->findApplication(appId)) {
+        if (m_list.at(index)->pinned()) {
+            m_list.at(index)->setPinned(false);
+            QModelIndex modelIndex = this->index(index);
+            Q_EMIT dataChanged(modelIndex, modelIndex, QVector<int>() << RolePinned);
+        }
+    } else {
+        beginRemoveRows(QModelIndex(), index, index);
+        m_list.takeAt(index)->deleteLater();
+        endRemoveRows();
+    }
 }
 
 int LauncherModel::findApplication(const QString &appId)
@@ -320,7 +328,6 @@ void LauncherModel::progressChanged(const QString &appId, int progress)
     }
 }
 
-
 void LauncherModel::countChanged(const QString &appId, int count)
 {
     int idx = findApplication(appId);
@@ -328,6 +335,7 @@ void LauncherModel::countChanged(const QString &appId, int count)
         LauncherItem *item = m_list.at(idx);
         item->setCount(count);
         Q_EMIT dataChanged(index(idx), index(idx), QVector<int>() << RoleCount);
+        m_asAdapter->syncItems(m_list);
     }
 }
 
@@ -356,28 +364,93 @@ void LauncherModel::countVisibleChanged(const QString &appId, int countVisible)
             beginInsertRows(QModelIndex(), m_list.count(), m_list.count());
             m_list.append(item);
             endInsertRows();
+            Q_EMIT hint();
         }
     }
+    m_asAdapter->syncItems(m_list);
 }
 
 void LauncherModel::refresh()
 {
+    // First walk through all the existing items and see if we need to remove something
     QList<LauncherItem*> toBeRemoved;
     Q_FOREACH (LauncherItem* item, m_list) {
         DesktopFileHandler desktopFile(item->appId());
         if (!desktopFile.isValid()) {
+            // Desktop file not available for this app => drop it!
+            toBeRemoved << item;
+        } else if (!m_settings->storedApplications().contains(item->appId())) {
+            // Item not in settings any more => drop it!
             toBeRemoved << item;
         } else {
             int idx = m_list.indexOf(item);
             item->setName(desktopFile.displayName());
             item->setIcon(desktopFile.icon());
+            item->setPinned(item->pinned()); // update pinned text if needed
             Q_EMIT dataChanged(index(idx), index(idx), QVector<int>() << RoleName << RoleIcon);
         }
     }
 
     Q_FOREACH (LauncherItem* item, toBeRemoved) {
-        requestRemove(item->appId());
+        unpin(item->appId());
     }
+
+    bool changed = toBeRemoved.count() > 0;
+
+    // This brings the Launcher into sync with the settings backend again. There's an issue though:
+    // If we can't find a .desktop file for an entry we need to skip it. That makes our settingsIndex
+    // go out of sync with the actual index of items. So let's also use an addedIndex which reflects
+    // the settingsIndex minus the skipped items.
+    int addedIndex = 0;
+
+    // Now walk through settings and see if we need to add something
+    for (int settingsIndex = 0; settingsIndex < m_settings->storedApplications().count(); ++settingsIndex) {
+        QString entry = m_settings->storedApplications().at(settingsIndex);
+        int itemIndex = -1;
+        for (int i = 0; i < m_list.count(); ++i) {
+            if (m_list.at(i)->appId() == entry) {
+                itemIndex = i;
+                break;
+            }
+        }
+
+        if (itemIndex == -1) {
+            // Need to add it. Just add it into the addedIndex to keep same ordering as the list
+            // in the settings.
+            DesktopFileHandler desktopFile(entry);
+            if (!desktopFile.isValid()) {
+                qWarning() << "Couldn't find a .desktop file for" << entry << ". Skipping...";
+                continue;
+            }
+
+            LauncherItem *item = new LauncherItem(entry,
+                                                  desktopFile.displayName(),
+                                                  desktopFile.icon(),
+                                                  this);
+            item->setPinned(true);
+            beginInsertRows(QModelIndex(), addedIndex, addedIndex);
+            m_list.insert(addedIndex, item);
+            endInsertRows();
+            changed = true;
+        } else if (itemIndex != addedIndex) {
+            // The item is already there, but it is in a different place than in the settings.
+            // Move it to the addedIndex
+            beginMoveRows(QModelIndex(), itemIndex, itemIndex, QModelIndex(), addedIndex);
+            m_list.move(itemIndex, addedIndex);
+            endMoveRows();
+            changed = true;
+        }
+
+        // Just like settingsIndex, this will increase with every item, except the ones we
+        // skipped with the "continue" call above.
+        addedIndex++;
+    }
+
+    if (changed) {
+        Q_EMIT hint();
+    }
+
+    m_asAdapter->syncItems(m_list);
 }
 
 void LauncherModel::applicationAdded(const QModelIndex &parent, int row)
@@ -395,14 +468,14 @@ void LauncherModel::applicationAdded(const QModelIndex &parent, int row)
         return;
     }
 
-    bool found = false;
-    Q_FOREACH(LauncherItem *item, m_list) {
-        if (app->appId() == item->appId()) {
-            found = true;
-            break;
+    int itemIndex = findApplication(app->appId());
+    if (itemIndex != -1) {
+        LauncherItem *item = m_list.at(itemIndex);
+        if (!item->recent()) {
+            item->setRecent(true);
+            m_asAdapter->syncItems(m_list);
+            Q_EMIT dataChanged(index(itemIndex), index(itemIndex), QVector<int>() << RoleRecent);
         }
-    }
-    if (found) {
         // Shall we paint some running/recent app highlight? If yes, do it here.
     } else {
         LauncherItem *item = new LauncherItem(app->appId(), app->name(), app->icon().toString(), this);
@@ -412,6 +485,7 @@ void LauncherModel::applicationAdded(const QModelIndex &parent, int row)
         beginInsertRows(QModelIndex(), m_list.count(), m_list.count());
         m_list.append(item);
         endInsertRows();
+        m_asAdapter->syncItems(m_list);
     }
 }
 
@@ -431,6 +505,7 @@ void LauncherModel::applicationRemoved(const QModelIndex &parent, int row)
         beginRemoveRows(QModelIndex(), appIndex, appIndex);
         m_list.takeAt(appIndex)->deleteLater();
         endRemoveRows();
+        m_asAdapter->syncItems(m_list);
     }
 }
 
