@@ -209,6 +209,21 @@ void MockLauncherModel::setApplicationManager(unity::shell::application::Applica
     Q_UNUSED(applicationManager)
 }
 
+bool MockLauncherModel::onlyPinned() const
+{
+    return false;
+}
+
+void MockLauncherModel::setOnlyPinned(bool onlyPinned)
+{
+    Q_UNUSED(onlyPinned)
+}
+
+void MockLauncherModel::emitHint()
+{
+    Q_EMIT hint();
+}
+
 unity::shell::application::ApplicationManagerInterface *MockLauncherModel::applicationManager() const
 {
     return nullptr;
