@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Canonical Ltd.
+ * Copyright 2013-2014 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,9 @@
 #include "launcheritem.h"
 #include "launchermodel.h"
 #include "dbusinterface.h"
+#include "gsettings.h"
+#include "asadapter.h"
+#include "AccountsServiceDBusAdaptor.h"
 
 #include <QtTest>
 #include <QDBusInterface>
@@ -81,7 +84,15 @@ public:
         return nullptr;
     }
     unity::shell::application::ApplicationInfoInterface *startApplication(const QString &, const QStringList &) { return nullptr; }
-    bool stopApplication(const QString &) { return false; }
+    bool stopApplication(const QString &appId) {
+        Q_FOREACH(MockApp* app, m_list) {
+            if (app->appId() == appId) {
+                removeApplication(m_list.indexOf(app));
+                return true;
+            }
+        }
+        return false;
+    }
     bool focusApplication(const QString &appId) {
         Q_FOREACH(MockApp* app, m_list) {
             app->setFocused(app->appId() == appId);
@@ -120,10 +131,16 @@ private:
     LauncherModel *launcherModel;
     MockAppManager *appManager;
 
+    QList<QVariantMap> getASConfig() {
+        AccountsServiceDBusAdaptor *as = launcherModel->m_asAdapter->m_accounts;
+        return as->getUserProperty("", "", "LauncherItems").value<QList<QVariantMap>>();
+    }
+
 private Q_SLOTS:
 
     void initTestCase() {
         launcherModel = new LauncherModel(this);
+        QCoreApplication::processEvents(); // to let the model register on DBus
         QCOMPARE(launcherModel->rowCount(QModelIndex()), 0);
 
         appManager = new MockAppManager(this);
@@ -137,6 +154,8 @@ private Q_SLOTS:
 
         appManager->addApplication(new MockApp("no-icon"));
         QCOMPARE(launcherModel->rowCount(QModelIndex()), 2);
+
+        launcherModel->m_settings->setStoredApplications(QStringList());
     }
 
     // Removing apps from appmanager and launcher as pinned ones would stick
@@ -172,14 +191,23 @@ private Q_SLOTS:
         launcherModel->pin(launcherModel->get(0)->appId());
         QCOMPARE(launcherModel->get(0)->pinned(), true);
         QCOMPARE(launcherModel->get(1)->pinned(), false);
-        QCOMPARE(spy.count(), 1);
+        QCOMPARE(spy.count() > 0, true);
         QCOMPARE(spy.at(0).at(2).value<QVector<int>>().first(), (int)LauncherModelInterface::RolePinned);
 
+        // App should be pinned now
+        spy.clear();
         launcherModel->requestRemove(launcherModel->get(0)->appId());
         QCOMPARE(launcherModel->get(0)->pinned(), false);
         QCOMPARE(launcherModel->get(1)->pinned(), false);
-        QCOMPARE(spy.count(), 2);
-        QCOMPARE(spy.at(1).at(2).value<QVector<int>>().first(), (int)LauncherModelInterface::RolePinned);
+        QCOMPARE(spy.count(), 1);
+        QCOMPARE(spy.at(0).at(2).value<QVector<int>>().first(), (int)LauncherModelInterface::RolePinned);
+
+        // Now that the app is unpinned, nothing should change and the signal should not be emitted
+        spy.clear();
+        launcherModel->requestRemove(launcherModel->get(0)->appId());
+        QCOMPARE(launcherModel->get(0)->pinned(), false);
+        QCOMPARE(launcherModel->get(1)->pinned(), false);
+        QCOMPARE(spy.count(), 0);
     }
 
     void testRemove_data() {
@@ -188,7 +216,7 @@ private Q_SLOTS:
         QTest::addColumn<bool>("running");
 
         QTest::newRow("non-pinned, running") << false << true;
-        QTest::newRow("pinned, running") << true << false;
+        QTest::newRow("pinned, running") << true << true;
         QTest::newRow("pinned, non-running") << true << false;
     }
 
@@ -201,23 +229,24 @@ private Q_SLOTS:
 
         // pin one if required
         if (pinned) {
-            launcherModel->pin(launcherModel->get(1)->appId());
+            launcherModel->pin("abs-icon");
         }
 
         // stop it if required
         if (!running) {
-            appManager->removeApplication(1);
+            appManager->stopApplication("abs-icon");
         }
 
         // Now remove it
-        launcherModel->requestRemove(launcherModel->get(1)->appId());
+        launcherModel->requestRemove("abs-icon");
 
         if (running) {
             // both apps are running, both apps must still be here
             QCOMPARE(launcherModel->rowCount(QModelIndex()), 2);
 
            // Item must be unpinned now
-           QCOMPARE(launcherModel->get(1)->pinned(), false);
+           int index = launcherModel->findApplication("abs-icon");
+           QCOMPARE(launcherModel->get(index)->pinned(), false);
 
         } else if (pinned) {
            // Item 1 must go away, item 0 is here to stay
@@ -226,7 +255,7 @@ private Q_SLOTS:
 
         // done our checks. now stop the app if was still running
         if (running) {
-            appManager->removeApplication(1);
+            appManager->stopApplication("abs-icon");
         }
 
         // It needs to go away in any case now
@@ -351,8 +380,8 @@ private Q_SLOTS:
         QCOMPARE(map.value("countVisible").toBool(), false);
 
         // Now make it visible and set it to 55 through D-Bus
-        interface.call("Set", "com.canonical.Unity.Launcher.Item", "count", 55);
-        interface.call("Set", "com.canonical.Unity.Launcher.Item", "countVisible", true);
+        interface.call("Set", "com.canonical.Unity.Launcher.Item", "count", QVariant::fromValue(QDBusVariant(55)));
+        interface.call("Set", "com.canonical.Unity.Launcher.Item", "countVisible", QVariant::fromValue(QDBusVariant(true)));
 
         // Fetch it again using GetAll
         reply = interface.call("GetAll");
@@ -371,12 +400,193 @@ private Q_SLOTS:
         QCOMPARE(launcherModel->get(index)->count(), 55);
     }
 
-    void testRefresh() {
+    void testCountEmblemAddsRemovesItem_data() {
+        QTest::addColumn<bool>("isPinned");
+        QTest::addColumn<bool>("isRunning");
+        QTest::addColumn<bool>("startWhenVisible");
+        QTest::newRow("not pinned, not running") << false << false << false;
+        QTest::newRow("pinned, not running") << true << false << false;
+        QTest::newRow("not pinned, not running, starting from notification") << false << false << true;
+        QTest::newRow("pinned, not running, starting from notification") << true << false << true;
+        QTest::newRow("not pinned, running") << false << true << false;
+        QTest::newRow("pinned, running") << true << true << false;
+    }
+
+    void testCountEmblemAddsRemovesItem() {
+        QFETCH(bool, isPinned);
+        QFETCH(bool, isRunning);
+        QFETCH(bool, startWhenVisible);
+
+        // Make sure item is here as expected after init() and that count is not visible
+        int index = launcherModel->findApplication("abs-icon");
+        QCOMPARE(index == -1, false);
+        QCOMPARE(launcherModel->get(index)->countVisible(), false);
+
+        // Pin if we need to
+        if (isPinned) {
+            launcherModel->pin("abs-icon");
+        }
+        QCOMPARE(launcherModel->get(0)->pinned(), isPinned);
+
+        // Stop it if we need to
+        if (!isRunning) {
+            appManager->stopApplication("abs-icon");
+        }
+        QCOMPARE(launcherModel->findApplication("abs-icon") >= 0, isRunning || isPinned);
+
+
+        // set the count emblem to visible
+        QDBusInterface interface("com.canonical.Unity.Launcher", "/com/canonical/Unity/Launcher/abs_2Dicon", "org.freedesktop.DBus.Properties");
+        interface.call("Set", "com.canonical.Unity.Launcher.Item", "count", QVariant::fromValue(QDBusVariant(55)));
+        interface.call("Set", "com.canonical.Unity.Launcher.Item", "countVisible", QVariant::fromValue(QDBusVariant(true)));
+
+        // Make sure item is here and that count is visible
+        index = launcherModel->findApplication("abs-icon");
+        QCOMPARE(index == -1, false);
+        QCOMPARE(launcherModel->get(index)->countVisible(), true);
+
+        if (!isRunning && startWhenVisible) {
+            appManager->addApplication(new MockApp("abs-icon"));
+        }
+
+        // Hide count emblem again
+        interface.call("Set", "com.canonical.Unity.Launcher.Item", "countVisible", QVariant::fromValue(QDBusVariant(false)));
+
+        // Make sure item is shown/hidden as expected
+        index = launcherModel->findApplication("abs-icon");
+        QCOMPARE(index == -1, !isRunning && !isPinned && !startWhenVisible);
+    }
+
+    void testRefreshAfterDeletedDesktopFiles_data() {
+        QTest::addColumn<bool>("deleted");
+        QTest::newRow("have .desktop files") << false;
+        QTest::newRow("deleted .desktop files") << true;
+    }
+
+    void testRefreshAfterDeletedDesktopFiles() {
+        QFETCH(bool, deleted);
+
+        // pin both apps
+        launcherModel->pin("abs-icon");
+        launcherModel->pin("no-icon");
+        // close both apps
+        appManager->removeApplication(0);
+        appManager->removeApplication(0);
+
+        // "delete" the .desktop files
+        QString oldCurrent = QDir::currentPath();
+        if (deleted) {
+            // In testing mode, the launcher searches the current dir for the sample .desktop file
+            // We can make that fail by changing the current dir
+            QDir::setCurrent("..");
+        }
+
+        // Call refresh
         QDBusInterface interface("com.canonical.Unity.Launcher", "/com/canonical/Unity/Launcher", "com.canonical.Unity.Launcher");
         QDBusReply<void> reply = interface.call("Refresh");
 
         // Make sure the call to Refresh returned without error.
         QCOMPARE(reply.isValid(), true);
+
+        QCOMPARE(launcherModel->rowCount(), deleted ? 0 : 2);
+
+        // Restoring current dir
+        QDir::setCurrent(oldCurrent);
+    }
+
+    void testSettings() {
+        GSettings *settings = launcherModel->m_settings;
+        QSignalSpy spy(launcherModel, SIGNAL(hint()));
+
+        // Nothing pinned at startup
+        QCOMPARE(settings->storedApplications().count(), 0);
+
+        // pin both apps
+        launcherModel->pin("abs-icon");
+        launcherModel->pin("no-icon");
+        QCOMPARE(spy.count(), 0);
+
+        // Now settings should have 2 apps
+        QCOMPARE(settings->storedApplications().count(), 2);
+
+        // close both apps
+        appManager->removeApplication(0);
+        appManager->removeApplication(0);
+
+        // Now settings should have 2 apps
+        QCOMPARE(settings->storedApplications().count(), 2);
+
+        // Now remove 1 app through the backend, make sure one is still there
+        settings->simulateDConfChanged(QStringList() << "abs-icon");
+        QCOMPARE(settings->storedApplications().count(), 1);
+        QCOMPARE(spy.count(), 1);
+
+        // Check if it disappeared from the frontend too
+        QCOMPARE(launcherModel->rowCount(), 1);
+
+        // Add them back but in reverse order
+        settings->simulateDConfChanged(QStringList() << "no-icon" << "abs-icon");
+        QCOMPARE(launcherModel->rowCount(), 2);
+        QCOMPARE(launcherModel->get(0)->appId(), QString("no-icon"));
+        QCOMPARE(launcherModel->get(1)->appId(), QString("abs-icon"));
+        QCOMPARE(spy.count(), 2);
+    }
+
+    void testAddSyncsToAS() {
+        // Make sure launcher and AS are in sync when we start the test
+        QCOMPARE(launcherModel->rowCount(), getASConfig().count());
+
+        int oldCount = launcherModel->rowCount();
+        appManager->addApplication(new MockApp("rel-icon"));
+        QCOMPARE(launcherModel->rowCount(), oldCount + 1);
+        QCOMPARE(launcherModel->rowCount(), getASConfig().count());
+    }
+
+    void testRemoveSyncsToAS() {
+        // Make sure launcher and AS are in sync when we start the test
+        QCOMPARE(launcherModel->rowCount(), getASConfig().count());
+
+        int oldCount = launcherModel->rowCount();
+        appManager->stopApplication("abs-icon");
+        QCOMPARE(launcherModel->rowCount(), oldCount - 1);
+        QCOMPARE(launcherModel->rowCount(), getASConfig().count());
+    }
+
+    void testMoveSyncsToAS() {
+        // Make sure launcher and AS are in sync when we start the test
+        QCOMPARE(launcherModel->rowCount(), getASConfig().count());
+
+        for (int i = 0; i < launcherModel->rowCount(); i++) {
+            QString launcherAppId = launcherModel->get(i)->appId();
+            QString asAppId = getASConfig().at(i).value("id").toString();
+            QCOMPARE(launcherAppId, asAppId);
+        }
+
+        launcherModel->move(0, 1);
+
+        for (int i = 0; i < launcherModel->rowCount(); i++) {
+            QString launcherAppId = launcherModel->get(i)->appId();
+            QString asAppId = getASConfig().at(i).value("id").toString();
+            QCOMPARE(launcherAppId, asAppId);
+        }
+    }
+
+    void testCountChangeSyncsToAS() {
+        // Find the index of the abs-icon app
+        int index = launcherModel->findApplication("abs-icon");
+
+        // Make sure it's invisible and 0 at the beginning
+        QCOMPARE(getASConfig().at(index).value("countVisible").toBool(), false);
+        QCOMPARE(getASConfig().at(index).value("count").toInt(), 0);
+
+        // Change the count of the abs-icon app through D-Bus
+        QDBusInterface interface("com.canonical.Unity.Launcher", "/com/canonical/Unity/Launcher/abs_2Dicon", "org.freedesktop.DBus.Properties");
+        interface.call("Set", "com.canonical.Unity.Launcher.Item", "count", QVariant::fromValue(QDBusVariant(55)));
+        interface.call("Set", "com.canonical.Unity.Launcher.Item", "countVisible", QVariant::fromValue(QDBusVariant(true)));
+
+        // Make sure it changed to visible and 55
+        QCOMPARE(getASConfig().at(index).value("countVisible").toBool(), true);
+        QCOMPARE(getASConfig().at(index).value("count").toInt(), 55);
     }
 };
 
